@@ -2,10 +2,10 @@ from python_framework import ResourceManager
 from queue_manager_api import QueueManager
 
 import ModelAssociation
-import NotificationManager
+from manager.NotificationManager import NotificationManager
 
 
 app = ResourceManager.initialize(__name__, ModelAssociation.MODEL, managerList=[
     QueueManager(),
-    NotificationManager.NotificationManager(addResources = False)
+    NotificationManager()
 ])
