@@ -2,22 +2,22 @@ from python_helper import log
 from python_framework import StaticConverter, Serializer
 
 try:
-    from constant import NotificationConstant
     from enumeration.NotificationSeverity import NotificationSeverity
     from enumeration.NotificationStatus import NotificationStatus
     from enumeration.NotificationDestiny import NotificationDestiny
+    from constant import NotificationConstant
 except:
     try:
-        from notification_manager_api.api.src.constant import NotificationConstant
         from notification_manager_api.api.src.enumeration.NotificationSeverity import NotificationSeverity
         from notification_manager_api.api.src.enumeration.NotificationStatus import NotificationStatus
         from notification_manager_api.api.src.enumeration.NotificationDestiny import NotificationDestiny
+        from notification_manager_api.api.src.constant import NotificationConstant
     except Exception as exception:
-        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
-        from notification_manager_api import NotificationConstant
+        log.warning(log.warning, 'There is most likely an issue related to queue-manager-api dependencies imports', exception=exception)
         from notification_manager_api import NotificationSeverity
         from notification_manager_api import NotificationStatus
         from notification_manager_api import NotificationDestiny
+        from notification_manager_api import NotificationConstant
 
 
 def toMessage(message):
