@@ -6,7 +6,7 @@ except:
     try:
         from notification_manager_api.api.src.converter.static import NotificationStaticConverter
     except Exception as exception:
-        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
+        log.warning(log.warning, 'There is most likely an issue related to queue-manager-api dependencies imports', exception=exception)
         from notification_manager_api import NotificationStaticConverter
 
 
